#!/bin/sh
# Postinstallation and post-uninstallation script for the MQSeriesKeyMan package

# This script customises the WMQ GSKIT installation using the current local
# install of the GSKIT package, as per the instruction given in the
# GSKIT SSL Tolkit Version 6b Install and Packaging Document 

PLATFORM=`uname`

# GSK_HOME is where GSKIT 6 is installed
# JAVA_HOME is where the WMQ JRE has been installed 

if [ "$PLATFORM" = "AIX" ]; then
  GSK_HOME=/usr/opt/ibm/gskak
  JAVA_HOME=/usr/mqm/ssl/jre
elif [ "$PLATFORM" = "Linux" ]; then
  GSK_HOME=/usr/local/ibm/gsk6
  JAVA_HOME=/opt/mqm/ssl/jre
elif [ "$PLATFORM" = "SunOS" ]; then
  GSK_HOME=/opt/ibm/gsk6
  JAVA_HOME=/opt/mqm/ssl
else
  GSK_HOME=/opt/ibm/gsk6
  JAVA_HOME=/opt/mqm/ssl/jre
fi

echo "Customizing WebSphere MQ GSkit installation on $PLATFORM ..."

# JARS is a list of the .jar files that are to be copied to the JRE
JARS="ibmjcefw.jar \
      ibmjceprovider.jar \
      ibmjlog.jar \
      ibmpkcs.jar \
      local_policy.jar \
      US_export_policy.jar"

#
#  Copy the jar files from the GSKit installed location
#
for i in $JARS ; do 
  if [ -f "$GSK_HOME/classes/jre/lib/ext/$i" ]; then
    cp -pf $GSK_HOME/classes/jre/lib/ext/$i $JAVA_HOME/lib/ext
    chown mqm:mqm $JAVA_HOME/lib/ext/$i
  fi
done

#  
# Copy the sample security file to the jre 
#  
if [ -f $GSK_HOME/classes/gsk_java.security ]; then
  cp -pf $GSK_HOME/classes/gsk_java.security $JAVA_HOME/lib/security/java.security
  chown mqm:mqm $JAVA_HOME/lib/security/java.security
fi

# Register the files with the local file database on appropriate platforms
if [ "$PLATFORM" = "SunOS" ]; then
  for i in $JARS ; do
    if [ -f "$JAVA_HOME/lib/ext/$i" ]; then
      echo "Registering $JAVA_HOME/lib/ext/$i"
      installf -c keyman mqm $JAVA_HOME/lib/ext/$i f
    fi
  done
  # Commit the changes
  installf -f -c keyman mqm
fi

echo "Customizing WebSphere MQ GSkit installation complete"

